#!/usr/bin/env node
import dotenvFlow from "dotenv-flow";
dotenvFlow.config({
  silent: true
});
import { Command } from "commander";
import { LIB_VERSION } from '../version/index.js';
import { makeGenerateCommand } from './migrations/command-generate.js';
import { makeStartCommand } from './docker-commands/command-start.js';
import { makeStopCommand } from './docker-commands/command-stop.js';
import { makeStatusCommand } from './docker-commands/command-status.js';
import { makePsqlCommand } from './docker-commands/command-psql.js';
import { makeShowConfigCommand } from './configure/command-show-config.js';
import { makeWithConfigCommand } from './configure/command-with-config.js';
import { makeProxyTunnelCommand } from './tunnel/command-proxy-tunnel.js';
async function main() {
  const program = new Command();
  program.name("npx electric-sql").description("CLI to enable building ElectricSQL projects in TypeScript").version(LIB_VERSION);
  [
    makeGenerateCommand,
    makeStartCommand,
    makeStopCommand,
    makeStatusCommand,
    makePsqlCommand,
    makeShowConfigCommand,
    makeWithConfigCommand,
    makeProxyTunnelCommand
  ].forEach((cmd) => program.addCommand(cmd()));
  await program.parseAsync(process.argv);
}
main();
//# sourceMappingURL=main.js.map