import { DatabaseAdapter } from './adapter.js';
import { createEmbeddedPostgres } from './database.js';
import { electrify as baseElectrify } from '../../electric/index.js';
import { WebSocketNode } from '../../sockets/node.js';
import { PgBundleMigrator } from '../../migrators/bundle.js';
const electrify = async (db, dbDescription, config, opts) => {
  const dbName = `${db.host}:${db.port}/${db.database ?? ""}`;
  const adapter = opts?.adapter || new DatabaseAdapter(db);
  const migrator = opts?.migrator || new PgBundleMigrator(adapter, dbDescription.pgMigrations);
  const socketFactory = opts?.socketFactory || WebSocketNode;
  const prepare = async (_connection) => void 0;
  const configWithDialect = {
    ...config,
    dialect: "Postgres"
  };
  const client = await baseElectrify(
    dbName,
    dbDescription,
    adapter,
    socketFactory,
    configWithDialect,
    {
      migrator,
      prepare,
      ...opts
    }
  );
  return client;
};
export {
  DatabaseAdapter,
  createEmbeddedPostgres,
  electrify
};
//# sourceMappingURL=index.js.map