import { genUUID } from './random.js';
const defaultKey = "electric-sql.utils.tab:id";
let tabId = null;
const uniqueTabId = (opts = {}) => {
  const key = opts.key ?? defaultKey;
  let storage;
  if (opts.storage !== void 0) {
    storage = opts.storage;
  } else {
    try {
      storage = window.sessionStorage;
    } catch {
      storage = {};
    }
  }
  let navEntries;
  if (opts.navEntries !== void 0) {
    navEntries = opts.navEntries;
  } else {
    try {
      navEntries = window.performance.getEntriesByType("navigation");
    } catch {
      navEntries = [];
    }
  }
  let existingTabId;
  let usedSessionStorage;
  try {
    existingTabId = storage.getItem(key);
    usedSessionStorage = true;
  } catch {
    existingTabId = tabId;
    usedSessionStorage = false;
  }
  const hasExisting = existingTabId !== null;
  if (hasExisting && !usedSessionStorage) {
    return {
      tabId: existingTabId,
      hasExisting: true,
      usingExisting: true
    };
  }
  const navEntry = navEntries && navEntries.length ? navEntries[0] : { type: null };
  const mayBeDuplicate = navEntry.type === "back_forward";
  if (hasExisting && !mayBeDuplicate) {
    return {
      tabId: existingTabId,
      hasExisting: true,
      usingExisting: true,
      mayBeDuplicate: false
    };
  }
  const newTabId = genUUID();
  try {
    storage.setItem(key, newTabId);
  } catch {
    tabId = newTabId;
  }
  return {
    tabId: newTabId,
    hasExisting,
    usingExisting: false,
    mayBeDuplicate
  };
};
export {
  uniqueTabId
};
//# sourceMappingURL=tab.js.map