import { ForeignKeyChecks } from '../config/index.js';
async function runInTransaction(adapter, fkChecks, ...stmts) {
  if (fkChecks === ForeignKeyChecks.inherit) {
    return adapter.runInTransaction(...stmts);
  }
  const desiredPragma = fkChecks === ForeignKeyChecks.disabled ? 0 : 1;
  return adapter.runExclusively(async (uncoordinatedAdapter) => {
    const [{ foreign_keys: originalPragma }] = await uncoordinatedAdapter.query(
      {
        sql: "PRAGMA foreign_keys;"
      }
    );
    if (originalPragma !== desiredPragma) {
      await uncoordinatedAdapter.run({
        sql: `PRAGMA foreign_keys = ${desiredPragma};`
      });
    }
    try {
      const res = await uncoordinatedAdapter.runInTransaction(...stmts);
      return res;
    } finally {
      if (originalPragma !== desiredPragma) {
        await uncoordinatedAdapter.run({
          sql: `PRAGMA foreign_keys = ${originalPragma};`
        });
      }
    }
  });
}
export {
  runInTransaction
};
//# sourceMappingURL=transactions.js.map